/*

Sound audio library
   
Copyright (c) 1999 Pascal Hofstee & Alain Kalker
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

$Id: plfunctions.c,v 1.2 1999/07/24 22:01:16 daeron Exp $

*/

#include "wsound.h"

extern WMPropList *WSoundDB;


WMPropList*
SGetObjectForKey(char *defaultName)
{
    WMPropList *object = NULL;
    WMPropList *key = WMCreatePLString(defaultName);

    object = WMGetFromPLDictionary(WSoundDB, key);

    WMReleasePropList(key);

    return object;
}


void
SSetObjectForKey(WMPropList *object, char *defaultName)
{
    WMPropList *key = WMCreatePLString(defaultName);

    WMPutInPLDictionary(WSoundDB, key, object);
    WMReleasePropList(key);
}


void
SRemoveObjectForKey(char *defaultName)
{
    WMPropList *key = WMCreatePLString(defaultName);
    
    WMRemoveFromPLDictionary(WSoundDB, key);
    
    WMReleasePropList(key);
}


char*
SGetStringForKey(char *defaultName)
{
    WMPropList *val;
    
    val = SGetObjectForKey(defaultName);

    if (!val)
	return NULL;

    if (!WMIsPLString(val))
	return NULL;

    return WMGetFromPLString(val);
}



WMPropList*
SGetArrayForKey(char *defaultName)
{
    WMPropList *val;
    
    val = SGetObjectForKey(defaultName);
    
    if (!val)
	return NULL;

    if (!WMIsPLArray(val))
	return NULL;

    return val;
}


WMPropList*
SGetDictionaryForKey(char *defaultName)
{
    WMPropList *val;

    val = SGetObjectForKey(defaultName);
    
    if (!val)
	return NULL;

    if (!WMIsPLDictionary(val))
	return NULL;

    return val;
}


int
SGetIntegerForKey(char *defaultName)
{
    WMPropList *val;
    char *str;
    int value;

    val = SGetObjectForKey(defaultName);
    
    if (!val)
	return 0;

    if (!WMIsPLString(val))
	return 0;
    
    str = WMGetFromPLString(val);
    if (!str)
	return 0;
    
    if (sscanf(str, "%i", &value)!=1)
	return 0;

    return value;
}


Bool
SGetBoolForKey(char *defaultName)
{
    int value;
    char *str;

    str = SGetStringForKey(defaultName);
    
    if (!str)
	return False;
    
    if (sscanf(str, "%i", &value)==1 && value!=0)
	return True;

    if (strcasecmp(str, "YES")==0)
	return True;
    
    if (strcasecmp(str, "Y")==0)
	return True;

    return False;
}


void
SSetIntegerForKey(int value, char *defaultName)
{
    WMPropList *object;
    char buffer[128];

    sprintf(buffer, "%i", value);
    object = WMCreatePLString(buffer);
 
    SSetObjectForKey(object, defaultName);
    WMReleasePropList(object);
}



void
SSetStringForKey(char *value, char *defaultName)
{
    WMPropList *object;

    object = WMCreatePLString(value);
 
    SSetObjectForKey(object, defaultName);
    WMReleasePropList(object);
}


void
SSetBoolForKey(Bool value, char *defaultName)
{
    static WMPropList *yes = NULL, *no = NULL;

    if (!yes) {
	yes = WMCreatePLString("YES");
	no = WMCreatePLString("NO");
    }

    SSetObjectForKey(value ? yes : no, defaultName);
}

